@@ -1,9 +1,10 @@
 from .bech32 import bech32_decode
+from .primitives import ShortChannelId, PublicKey
 from .invoice import Invoice
 from .onion import OnionPayload, TlvPayload, LegacyOnionPayload
 from .wire import LightningConnection, LightningServerSocket
 
-__version__ = '0.10.1'
+__version__ = "0.11.0"
 
 __all__ = [
     "Invoice",
@@ -13,4 +14,7 @@ __all__ = [
     "LegacyOnionPayload",
     "TlvPayload",
     "bech32_decode",
+    "ShortChannelId",
+    "PublicKey",
+    "__version__",
 ]
